@@ -84,4 +84,4 @@ def home():
 
 
 def main():
-    app.run(host="0.0.0.0")
+    app.run(host="0.0.0.0", port=8080)
